@@ -1,11 +1,10 @@
-from collections import defaultdict
-import yaml
 import os
 import argparse
 import aithermal
 import pandas as pd
 import xlsxwriter
 import simplelogging
+import oyaml as yaml
 
 
 def main():
@@ -23,36 +22,39 @@ def main():
     try:
         with open(parameters, "r") as stream:
             data_loaded = yaml.safe_load(stream)
-            try:
-                _run(*decomporess(data_loaded))
-            except TypeError as e:
-                print("Please double-check your parameters.yaml document'")
-                log.exception(e)
-                os.startfile(os.path.join(os.getcwd(), "parameters.yaml"))
     except FileNotFoundError as e:
         data_loaded = aithermal.utils.write_yaml()
         with open("project parameters.yaml", "w") as outfile:
             yaml.dump(data_loaded, outfile, default_flow_style=False)
-        print("Please fill out the parameter.yaml document")
+        print("Please fill out the project parameters.yaml document")
         log.exception(f"{FileNotFoundError} {e}")
-        os.startfile(os.path.join(os.getcwd(), "parameters.yaml"))
+        os.startfile(os.path.join(os.getcwd(), "project parameters.yaml"))
+    try:
+        _run(*decomporess(data_loaded))
+    except TypeError as e:
+        raise e
+        print("Please double-check your project parameters.yaml document'")
+        log.exception(e)
+        os.startfile(os.path.join(os.getcwd(), "project parameters.yaml"))
 
 
 def decomporess(data_loaded):
     wavelenths = data_loaded.get("WAVE LENGTHS")
     gradient = data_loaded.get("GRADIENT")
-    rms = data_loaded.get("RMS")
+    # rms = data_loaded.get("RMS") #TODO: Support RMS
     root = data_loaded.get("PROJECT DIRECTORY")
     isotherms = data_loaded.get("ISOTHERMS")
     baselines = data_loaded.get("BASELINE DIRECTORY")
 
-    methods = [method for method in data_loaded.get("Techniques").keys() if method]
+    methods = [method for method in data_loaded.get("TECHNIQUES").keys() if method]
     topics, topic_paths = aithermal.topic_directories(root)
-    method_paths = aithermal.method_directories(topic_paths, topics, isotherms, methods)
-    return gradient, method_paths, rms, root, wavelenths, baselines
+    method_paths = aithermal.method_directories(
+        topic_paths, topics, gradient, isotherms, methods
+    )
+    return gradient, method_paths, root, wavelenths, baselines
 
 
-def _run(gradient, method_paths, rms, root, wavelengths, baseline_path):
+def _run(gradient, method_paths, root, wavelengths, baseline_path):
     ir_list, ms_list, sta_list, gc_list = aithermal.method_sorting(method_paths)
 
     sta_frames = aithermal.load_dsc(sta_list, baseline_path=baseline_path, method="tg")
