@@ -5,15 +5,14 @@ from collections import defaultdict
 
 
 def write_yaml():
-    tests = os.path.join(os.getcwd(), "tests")
     return {
         "BASELINE DIRECTORY": "",
-        "PROJECT DIRECTORY": tests,
+        "PROJECT DIRECTORY": "",
         "WAVE LENGTHS": [None, None, None, None],
         "GRADIENT": 30,
-        "RMS": False,
+        # "RMS": False, TODO: Support RMS
         "ISOTHERMS": [190, 220, 350],
-        "Techniques": {"STA": True, "IR": True, "GC": False, "MS": True},
+        "TECHNIQUES": {"STA": True, "IR": True, "GC": False, "MS": True},
     }
 
 
@@ -123,10 +122,10 @@ def topic_directories(path) -> (list, list):
     return topics, directories
 
 
-def method_directories(topic_paths, topics, isotherms, methods):
+def method_directories(topic_paths, topics, gradient, isotherms, methods):
     full = defaultdict(list)
     temp = defaultdict()
-    md = _construct_methods_listing(isotherms, methods)
+    md = _construct_methods_listing(gradient, isotherms, methods)
     for topic_directory, topic in zip(topic_paths, topics):
         for key in md.keys():
             for item in md[key]:
@@ -158,7 +157,7 @@ def method_sorting(method_paths):
     return ir_list, ms_list, sta_list, gc_list
 
 
-def _construct_methods_listing(isotherms, methods):
+def _construct_methods_listing(gradient, isotherms, methods):
     root = ["Data"]
     type = ["Gradient", ["Gradient", "Isotherm"]][len(isotherms) > 0]
     method_dict = defaultdict(list)
@@ -169,6 +168,8 @@ def _construct_methods_listing(isotherms, methods):
                     for r in root:
                         method_dict["isotherm"].append(f"{r}\\{t}\\{i}\\{m}")
             else:
+                for r in root:
+                    method_dict["gradient"].append(f"{r}\\{t}\\{gradient}\\{m}")
                 for r in root:
                     method_dict["gradient"].append(f"{r}\\{t}\\{m}")
 
